##############################################################################
# Copyright (c) 2013-2017, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
#
# This file is part of Spack.
# Created by Todd Gamblin, tgamblin@llnl.gov, All rights reserved.
# LLNL-CODE-647188
#
# For details, see https://github.com/spack/spack
# Please also see the NOTICE and LICENSE files for our notice and the LGPL.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License (as
# published by the Free Software Foundation) version 2.1, February 1999.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the IMPLIED WARRANTY OF
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the terms and
# conditions of the GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##############################################################################

import pytest
import spack.modules.dotkit

#: Class of the writer tested in this module
writer_cls = spack.modules.dotkit.DotkitModulefileWriter


@pytest.mark.usefixtures('config', 'builtin_mock')
class TestDotkit(object):

    def test_dotkit(self, modulefile_content, patch_configuration):
        """Tests the generation of a dotkit file that loads dependencies
        automatically.
        """

        patch_configuration('autoload_direct')
        content = modulefile_content('mpileaks arch=x86-linux')

        assert '#c spack' in content
        assert '#d mpileaks @2.3' in content
        assert len([x for x in content if 'dk_op' in x]) == 2

    @pytest.mark.usefixtures('update_template_dirs')
    def test_override_template_in_package(
            self, modulefile_content, patch_configuration
    ):
        """Tests overriding a template from and attribute in the package."""

        patch_configuration('autoload_direct')
        content = modulefile_content('override-module-templates')

        assert 'Override successful!' in content

    @pytest.mark.usefixtures('update_template_dirs')
    def test_override_template_in_modules_yaml(
            self, modulefile_content, patch_configuration
    ):
        """Tests overriding a template from `modules.yaml`"""

        patch_configuration('override_template')

        # Check that this takes precedence over an attribute in the package
        content = modulefile_content('override-module-templates')
        assert 'Override even better!' in content

        content = modulefile_content('mpileaks arch=x86-linux')
        assert 'Override even better!' in content
